@@ -6,9 +6,10 @@ import os
 import re
 import sys
 import time
-from typing import List, Dict, Callable
+from typing import Any, List, Dict, Callable
 import yaml
 import numpy as np
+from numpy import ndarray
 import click
 
 from rich.console import Console
@@ -134,7 +135,7 @@ class Card:
     def fan_speed(self) -> int:
         try:
             return int(self.read_endpoint("fan1_input"))
-        except KeyError:  # better to return no speed then explode
+        except (KeyError, OSError):  # better to return no speed then explode
             return 0
 
     @property
@@ -170,7 +171,7 @@ class Card:
 
 
 class Scanner:  # pylint: disable=too-few-public-methods
-    """ Used to scan the available cards to see if they are usable """
+    """Used to scan the available cards to see if they are usable"""
 
     CARD_REGEX: str = r"^card\d$"
 
@@ -199,7 +200,7 @@ class Scanner:  # pylint: disable=too-few-public-methods
 
 
 class FanController:  # pylint: disable=too-few-public-methods
-    """ Used to apply the curve at regular intervals """
+    """Used to apply the curve at regular intervals"""
 
     def __init__(self, config) -> None:
         self._scanner = Scanner(config.get("cards"))
@@ -292,7 +293,7 @@ class Curve:  # pylint: disable=too-few-public-methods
         if np.min(self.speeds) <= 3:
             raise ValueError("Lowest speed value to be set to 4")  # Driver BUG
 
-    def get_speed(self, temp: int) -> int:
+    def get_speed(self, temp: int) -> ndarray[Any, Any]:
         """
         returns a speed for a given temperature
         :param temp: int
